@@ -3,6 +3,7 @@ from __future__ import annotations
 from collections import Counter, defaultdict
 from collections.abc import Iterable
 from dataclasses import dataclass
+from enum import Enum
 from functools import total_ordering
 
 from sortedcontainers import SortedSet, SortedList
@@ -11,8 +12,9 @@ from plagdef.model import util
 
 
 class Document:
-    def __init__(self, name: str, text: str):
+    def __init__(self, name: str, path: str, text: str):
         self.name = name
+        self.path = path
         self.text = text
         self.vocab = Counter()  # <lemma, sent_freq>
         self._sents = SortedSet(key=lambda sent: sent.start_char)
@@ -31,11 +33,11 @@ class Document:
 
     def __eq__(self, other):
         if type(other) is type(self):
-            return self.name == other.name and self.text == other.text
+            return self.name == other.name and self.path == other.path
         return False
 
     def __hash__(self):
-        return hash((self.name, self.text))
+        return hash((self.name, self.path))
 
     def __repr__(self):
         return f"Document('{self.name}')"
@@ -66,6 +68,9 @@ class Fragment:
     def __len__(self):
         return self.end_char - self.start_char
 
+    def __repr__(self):
+        return f'Fragment({self.doc.name}, {self.start_char}, {self.end_char})'
+
 
 class Sentence(Fragment):
     def __init__(self, start_char: int, end_char: int, bow: Counter, doc: Document):
@@ -198,12 +203,7 @@ class Cluster:
         return hash(self.seeds)
 
     def __repr__(self):
-        if not len(self.seeds):
-            return 'Cluster()'
-        string = 'Cluster('
-        for seed in self.seeds:
-            string = string + f'{repr(seed)}, '
-        return f'{string[:-2]})'
+        return f'Cluster({len(self.seeds)}, {self.cos_sim})'
 
 
 @total_ordering
@@ -257,9 +257,16 @@ class Match:
     def __len__(self):
         return sum([len(frag) for frag in self.frag_pair])
 
+    def __repr__(self):
+        if len(self.frag_pair) < 2:
+            return 'Match()'
+        frag1, frag2 = self.frag_pair
+        return f'Match({frag1}, {frag2})'
+
 
 class DocumentPairMatches:
-    def __init__(self, matches=None):
+    def __init__(self, plag_type: PlagiarismType, matches=None):
+        self.plag_type = plag_type
         self.doc_pair = set()
         self._matches = set()
         if matches:
@@ -280,6 +287,12 @@ class DocumentPairMatches:
     def __len__(self):
         return len(self._matches)
 
+    def __repr__(self):
+        if len(self.doc_pair) < 2:
+            return 'DocPairMatches()'
+        doc1, doc2 = self.doc_pair
+        return f'DocPairMatches({doc1}, {doc2}, {len(self)})'
+
 
 class DifferentDocumentPairError(Exception):
     pass
@@ -287,3 +300,15 @@ class DifferentDocumentPairError(Exception):
 
 class SameDocumentError(Exception):
     pass
+
+
+@total_ordering
+class PlagiarismType(Enum):
+    VERBATIM = 1,
+    INTELLIGENT = 2,
+    SUMMARY = 3
+
+    def __lt__(self, other):
+        if self.__class__ is other.__class__:
+            return self.value < other.value
+        return NotImplemented
